tsseg.algorithms.vqtss package
==============================

VQ-VAE + InfoNCE contrastive objective for discrete state codes.

| **Type:** state detection
| **Supervision:** fully unsupervised
| **Requires:** PyTorch

**Implementation:** *Origin: new code.*

Submodules
----------

tsseg.algorithms.vqtss.detector module
--------------------------------------

.. automodule:: tsseg.algorithms.vqtss.detector
   :members:
   :show-inheritance:
   :undoc-members:

Module contents
---------------

.. automodule:: tsseg.algorithms.vqtss
   :members:
   :show-inheritance:
   :undoc-members:
